@@ -10,6 +10,8 @@ from ...jsonrpc2.server import JsonRPCServer, JsonRpcServerMode, TcpParams
 from ...utils.logging import LoggingDescriptor
 from ..client import DAPClient, DAPClientError
 from ..dap_types import (
+    AttachRequest,
+    AttachRequestArguments,
     Capabilities,
     ConfigurationDoneArguments,
     ConfigurationDoneRequest,
@@ -17,6 +19,7 @@ from ..dap_types import (
     DisconnectRequest,
     Event,
     ExceptionBreakpointsFilter,
+    InitializeRequest,
     InitializeRequestArguments,
     LaunchRequestArguments,
     OutputCategory,
@@ -57,6 +60,7 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
         super().__init__()
         self._client: Optional[DAPClient] = None
         self._process: Optional[asyncio.subprocess.Process] = None
+        self._initialize_arguments: Optional[InitializeRequestArguments] = None
 
     @property
     def client(self) -> DAPClient:
@@ -75,6 +79,8 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
 
     @rpc_method(name="initialize", param_type=InitializeRequestArguments)
     async def _initialize(self, arguments: InitializeRequestArguments, *args: Any, **kwargs: Any) -> Capabilities:
+        self._initialize_arguments = arguments
+
         self._initialized = True
 
         return Capabilities(
@@ -256,19 +262,23 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
             )
 
         else:
-            raise Exception(f'Unknown console type "{console}".')
+            raise ValueError(f'Unknown console type "{console}".')
 
         self.client = DAPClient(self, TcpParams(None, port))
         try:
             await self.client.connect(connect_timeout)
         except asyncio.TimeoutError:
-            raise asyncio.TimeoutError("Can't connect to debug launcher.")
+            raise asyncio.TimeoutError("Can't connect to debug child.")
+
+        if self._initialize_arguments is not None:
+            await self.client.protocol.send_request_async(InitializeRequest(arguments=self._initialize_arguments))
 
     @rpc_method(name="configurationDone", param_type=ConfigurationDoneArguments)
     async def _configuration_done(
         self, arguments: Optional[ConfigurationDoneArguments] = None, *args: Any, **kwargs: Any
     ) -> None:
         await self.client.protocol.send_request_async(ConfigurationDoneRequest(arguments=arguments))
+        await self.client.protocol.send_request_async(AttachRequest(arguments=AttachRequestArguments()))
 
     @rpc_method(name="disconnect", param_type=DisconnectArguments)
     async def _disconnect(self, arguments: Optional[DisconnectArguments] = None, *args: Any, **kwargs: Any) -> None:
@@ -276,16 +286,16 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
             if not self.client.protocol.terminated:
                 await self.client.protocol.send_request_async(DisconnectRequest(arguments=arguments))
         else:
+            self.send_event(Event("disconnectRequested"))
             await self.send_event_async(TerminatedEvent())
 
     @_logger.call
     @rpc_method(name="terminate", param_type=TerminateArguments)
     async def _terminate(self, arguments: Optional[TerminateArguments] = None, *args: Any, **kwargs: Any) -> None:
         if self.client.connected:
-            self.send_event(Event("terminateRequested"))
-
             return await self.client.protocol.send_request_async(TerminateRequest(arguments=arguments))
         else:
+            self.send_event(Event("terminateRequested"))
             await self.send_event_async(TerminatedEvent())
 
     async def handle_unknown_command(self, message: Request) -> Any:
