@@ -173,4 +173,10 @@ class SemanticTokensProtocolPart(LanguageServerProtocolPart, HasExtendCapabiliti
         return None
 
     async def workspace_refresh(self) -> None:
-        await self.parent.send_request_async("workspace/semanticTokens/refresh")
+        if (
+            self.parent.client_capabilities is not None
+            and self.parent.client_capabilities.workspace is not None
+            and self.parent.client_capabilities.workspace.semantic_tokens is not None
+            and self.parent.client_capabilities.workspace.semantic_tokens.refresh_support
+        ):
+            await self.parent.send_request_async("workspace/semanticTokens/refresh")
