@@ -41,7 +41,12 @@ from ..diagnostics.library_doc import (
     KeywordMatcher,
     LibraryDoc,
 )
-from ..diagnostics.namespace import LibraryEntry, Namespace, ResourceEntry
+from ..diagnostics.namespace import (
+    DEFAULT_BDD_PREFIXES,
+    LibraryEntry,
+    Namespace,
+    ResourceEntry,
+)
 from ..utils import async_ast
 from ..utils.ast_utils import (
     HasTokens,
@@ -214,7 +219,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                 }
             )
 
-        if get_robot_version() >= (5, 1):
+        if get_robot_version() >= (6, 0):
             definition.update(
                 {
                     frozenset(
@@ -241,7 +246,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         return cls.__mapping
 
     ESCAPE_REGEX = re.compile(
-        r"(?P<t>[^\\]+)|(?P<x>\\([^xuU]|x[0-f]{2}|u[0-f]{4}|U[0-f]{8}){0,1})", re.MULTILINE | re.DOTALL
+        r"(?P<t>[^\\]+)|(?P<x>\\([^xuU]|x[0-0a-f]{2}|u[0-9a-f]{4}|U[0-9a-f]{8}){0,1})", re.MULTILINE | re.DOTALL
     )
     BDD_TOKEN_REGEX = re.compile(r"^(Given|When|Then|And|But)\s", flags=re.IGNORECASE)
 
@@ -331,20 +336,22 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                 if await namespace.find_keyword(token.value, raise_keyword_error=False, handle_bdd_style=False) is None:
                     bdd_len = 0
 
-                    if get_robot_version() < (5, 1):
+                    if get_robot_version() < (6, 0):
                         bdd_match = cls.BDD_TOKEN_REGEX.match(token.value)
                         if bdd_match:
                             bdd_len = len(bdd_match.group(1))
                     else:
-                        parts = token.value.split(maxsplit=1)
-                        if len(parts) == 2:
-                            prefix, _ = parts
-                            if prefix.title() in (
-                                namespace.languages.bdd_prefixes
-                                if namespace.languages is not None
-                                else {"Given ", "When ", "Then ", "And ", "But "}
-                            ):
-                                bdd_len = len(prefix)
+                        parts = token.value.split()
+                        if len(parts) > 1:
+                            for index in range(1, len(parts)):
+                                prefix = " ".join(parts[:index]).title()
+                                if prefix.title() in (
+                                    namespace.languages.bdd_prefixes
+                                    if namespace.languages is not None
+                                    else DEFAULT_BDD_PREFIXES
+                                ):
+                                    bdd_len = len(prefix)
+                                    break
 
                     if bdd_len > 0:
                         yield SemTokenInfo.from_token(
