@@ -2,12 +2,12 @@ from __future__ import annotations
 
 import asyncio
 import concurrent.futures
-import contextlib
 import contextvars
 import functools
 import inspect
 import threading
 import time
+import warnings
 import weakref
 from collections import deque
 from concurrent.futures.thread import ThreadPoolExecutor
@@ -283,9 +283,6 @@ def check_canceled_sync() -> bool:
     return True
 
 
-# __threadpool_executor = ThreadPoolExecutor(thread_name_prefix="sub_asyncio")
-
-
 def run_in_thread(func: Callable[..., _T], /, *args: Any, **kwargs: Any) -> asyncio.Future[_T]:
     global __tread_pool_executor
 
@@ -294,12 +291,6 @@ def run_in_thread(func: Callable[..., _T], /, *args: Any, **kwargs: Any) -> asyn
     ctx = contextvars.copy_context()
     func_call = functools.partial(ctx.run, func, *args, **kwargs)
 
-    # return cast(
-    #     "asyncio.Future[_T]",
-    #     # loop.run_in_executor(__threadpool_executor, cast(Callable[..., _T], func_call)),
-    #     loop.run_in_executor(None, cast(Callable[..., _T], func_call)),
-    # )
-
     executor = ThreadPoolExecutor(max_workers=1, thread_name_prefix="sub_asyncio")
     try:
         return cast(
@@ -331,7 +322,7 @@ def run_coroutine_in_thread(
         if ct is not None and result is not None:
             _running_tasks[result].children.add(ct)
 
-        inner_task = create_sub_task(coro(*args, **kwargs))
+        inner_task = create_sub_task(coro(*args, **kwargs), name=coro.__qualname__)
 
         if canceled:
             inner_task.cancel()
@@ -339,33 +330,9 @@ def run_coroutine_in_thread(
         return await inner_task
 
     def run(coro: Callable[..., Coroutine[Any, Any, _T]], *args: Any, **kwargs: Any) -> _T:
-
-        old_name = threading.current_thread().name
         threading.current_thread().name = coro.__qualname__
-        try:
-            return asyncio.run(create_inner_task(coro, *args, **kwargs))
-        finally:
-            threading.current_thread().name = old_name
 
-        # loop = asyncio.new_event_loop()
-
-        # try:
-        #     asyncio.set_event_loop(loop)
-
-        #     t = loop.create_task(create_inner_task(coro, *args, **kwargs), name=coro.__qualname__)
-
-        #     return loop.run_until_complete(t)
-        # finally:
-        #     try:
-        #         running_tasks = asyncio.all_tasks(loop)
-        #         if running_tasks:
-        #             loop.run_until_complete(asyncio.gather(*running_tasks, return_exceptions=True))
-
-        #         loop.run_until_complete(loop.shutdown_asyncgens())
-        #     finally:
-        #         asyncio.set_event_loop(None)
-        #         loop.close()
-        #         threading.current_thread().setName(old_name)
+        return asyncio.run(create_inner_task(coro, *args, **kwargs))
 
     cti = get_current_future_info()
     result = run_in_thread(run, coro, *args, **kwargs)
@@ -389,28 +356,6 @@ def run_coroutine_in_thread(
     return result
 
 
-@contextlib.asynccontextmanager
-async def async_lock(lock: threading.RLock) -> AsyncGenerator[None, None]:
-    import time
-
-    start_time = time.monotonic()
-    locked = lock.acquire(blocking=False)
-    while not locked:
-        if time.monotonic() - start_time >= 1800:
-            raise TimeoutError("Timeout waiting for lock")
-
-        await asyncio.sleep(0.001)
-
-        locked = lock.acquire(blocking=False)
-    try:
-        yield
-    finally:
-        if locked:
-            lock.release()
-    # with lock:
-    #     yield
-
-
 class Event:
     """Thread safe version of an async Event"""
 
@@ -456,8 +401,15 @@ class Event:
 
                                 fut.get_loop().call_soon_threadsafe(set_result, fut, done)
 
-                                if not done.wait(120):
-                                    raise TimeoutError("Callback timeout.")
+                                start = time.monotonic()
+                                while not done.is_set():
+                                    check_canceled_sync()
+
+                                    if time.monotonic() - start > 120:
+                                        warnings.warn("Can't set future result.")
+                                        break
+
+                                    time.sleep(0.001)
 
     def clear(self) -> None:
         with self._lock:
@@ -478,147 +430,13 @@ class Event:
             return False
 
 
-class Semaphore:
-    """Thread safe version of a Semaphore"""
-
-    def __init__(self, value: int = 1) -> None:
-        if value < 0:
-            raise ValueError("Semaphore initial value must be >= 0")
-        self._value = value
-        self._waiters: Deque[asyncio.Future[Any]] = deque()
-
-        self._lock = threading.RLock()
-
-    def __repr__(self) -> str:
-        res = super().__repr__()
-        extra = "locked" if self.locked() else f"unlocked, value:{self._value}"
-        if self._waiters:
-            extra = f"{extra}, waiters:{len(self._waiters)}"
-        return f"<{res[1:-1]} [{extra}]>"
-
-    async def _wake_up_next(self) -> None:
-        async with async_lock(self._lock):
-            while self._waiters:
-                waiter = self._waiters.popleft()
-
-                if not waiter.done():
-                    if waiter.get_loop() == asyncio.get_running_loop():
-                        if not waiter.done():
-                            waiter.set_result(True)
-                    else:
-                        if waiter.get_loop().is_running():
-
-                            def set_result(w: asyncio.Future[Any], ev: threading.Event) -> None:
-                                try:
-                                    if w.get_loop().is_running() and not w.done():
-                                        w.set_result(True)
-                                finally:
-                                    ev.set()
-
-                            if not waiter.done():
-                                done = threading.Event()
-
-                                waiter.get_loop().call_soon_threadsafe(set_result, waiter, done)
-
-                                start = time.monotonic()
-                                while not done.is_set():
-
-                                    if time.monotonic() - start > 120:
-                                        raise TimeoutError("Can't set future result.")
-
-                                    await asyncio.sleep(0.001)
-
-    def locked(self) -> bool:
-        with self._lock:
-            return self._value == 0
-
-    async def acquire(self, timeout: Optional[float] = None) -> bool:
-        while True:
-            async with async_lock(self._lock):
-                if self._value > 0:
-                    break
-                fut = create_sub_future()
-                self._waiters.append(fut)
-
-            try:
-                await asyncio.wait_for(fut, timeout)
-            except asyncio.TimeoutError:
-                return False
-            except (SystemExit, KeyboardInterrupt):
-                raise
-
-            except BaseException:
-                if not fut.done():
-                    fut.cancel()
-                if self._value > 0 and not fut.cancelled():
-                    await self._wake_up_next()
-
-                raise
-
-        async with async_lock(self._lock):
-            self._value -= 1
-
-        return True
-
-    async def release(self) -> None:
-        self._value += 1
-        await self._wake_up_next()
-
-    async def __aenter__(self) -> None:
-        await self.acquire()
-
-    async def __aexit__(
-        self, exc_type: Optional[Type[BaseException]], exc_val: Optional[BaseException], exc_tb: Optional[TracebackType]
-    ) -> None:
-        await self.release()
-
-
-class BoundedSemaphore(Semaphore):
-    """Thread safe version of a BoundedSemaphore"""
-
-    def __init__(self, value: int = 1) -> None:
-        self._bound_value = value
-        super().__init__(value)
-
-    async def release(self) -> None:
-        if self._value >= self._bound_value:
-            raise ValueError("BoundedSemaphore released too many times")
-        await super().release()
-
-
 class Lock:
-    def __init__(self) -> None:
-        self._block = BoundedSemaphore(value=1)
-
-    def __repr__(self) -> str:
-        return "<%s _block=%s>" % (self.__class__.__name__, self._block)
-
-    async def acquire(self, timeout: Optional[float] = None) -> bool:
-        return await self._block.acquire(timeout)
-
-    async def release(self) -> None:
-        await self._block.release()
-
-    @property
-    def locked(self) -> bool:
-        return self._block.locked()
-
-    async def __aenter__(self) -> None:
-        await self.acquire()
-
-    async def __aexit__(
-        self, exc_type: Optional[Type[BaseException]], exc_val: Optional[BaseException], exc_tb: Optional[TracebackType]
-    ) -> None:
-        await self.release()
-
-
-class OldLock:
     """Threadsafe version of an async Lock."""
 
     def __init__(self) -> None:
         self._waiters: Optional[Deque[asyncio.Future[Any]]] = None
         self._locked = False
-        self._lock = threading.RLock()
+        self._lock = threading.Lock()
 
     async def __aenter__(self) -> None:
         await self.acquire()
@@ -637,16 +455,13 @@ class OldLock:
 
     @asynccontextmanager
     async def __inner_lock(self) -> AsyncGenerator[Any, None]:
-        b = self._lock.acquire(blocking=False)
-        while not b:
-            await asyncio.sleep(0)
-            b = self._lock.acquire(blocking=False)
+        while not (b := self._lock.acquire(blocking=False)):
+            await asyncio.sleep(0.001)
         try:
             yield None
         finally:
-            self._lock.release()
-        # with self._lock:
-        #     yield None
+            if b:
+                self._lock.release()
 
     @property
     def locked(self) -> bool:
@@ -665,16 +480,13 @@ class OldLock:
             self._waiters.append(fut)
 
         try:
-            try:
-                await fut
-            finally:
-                async with self.__inner_lock():
-                    if fut in self._waiters:
-                        self._waiters.remove(fut)
-                    self._locked = True
-        except asyncio.CancelledError:
-            await self._wake_up_next()
-            raise
+            # await asyncio.wait_for(fut, 120)
+            await fut
+        finally:
+            async with self.__inner_lock():
+                if fut in self._waiters:
+                    self._waiters.remove(fut)
+                self._locked = True
 
         return True
 
@@ -698,11 +510,11 @@ class OldLock:
             if fut in self._waiters:
                 self._waiters.remove(fut)
 
-        if fut.get_loop() == asyncio.get_running_loop():
-            if not fut.done():
-                fut.set_result(True)
-        else:
-            if fut.get_loop().is_running():
+        if fut.get_loop().is_running() and not fut.get_loop().is_closed():
+            if fut.get_loop() == asyncio.get_running_loop():
+                if not fut.done():
+                    fut.set_result(True)
+            else:
 
                 def set_result(w: asyncio.Future[Any], ev: threading.Event) -> None:
                     try:
@@ -720,12 +532,13 @@ class OldLock:
                     while not done.is_set():
 
                         if time.monotonic() - start > 120:
-                            raise TimeoutError("Can't set future result.")
+                            warnings.warn("Can't set future result.")
+                            break
 
                         await asyncio.sleep(0.001)
-
-                    # if not done.wait(120):
-                    #     raise TimeoutError("Callback timeout.")
+        else:
+            warnings.warn(f"Future {repr(fut)} loop is closed")
+            await self._wake_up_next()
 
 
 class FutureInfo:
